==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-common/src/test/java/org/apache/asterix/test/server/RSSTestServer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.test.server;

import org.apache.hyracks.http.server.HttpServer;
import org.apache.hyracks.http.server.WebManager;

public class RSSTestServer implements ITestServer {

    private WebManager webManager;

    public RSSTestServer(int port) {
        webManager = new WebManager();
        HttpServer rssServer = new HttpServer(webManager.getBosses(), webManager.getWorkers(), port);
        rssServer.addServlet(new RSSFeedServlet(null, new String[] { "/" }));
        webManager.add(rssServer);
    }

    @Override
    public void configure(String[] args) {
    }

    @Override
    public void start() throws Exception {
        webManager.start();
    }

    @Override
    public void stop() throws Exception {
        webManager.stop();
    }

}

==> apache-asterixdb-0.9.7.1-source-release.zip: apache-asterixdb-0.9.7.1/asterix-common/src/test/java/org/apache/asterix/test/server/RSSTestServer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.test.server;

import org.apache.hyracks.http.server.HttpServer;
import org.apache.hyracks.http.server.HttpServerConfigBuilder;
import org.apache.hyracks.http.server.WebManager;

public class RSSTestServer implements ITestServer {

    private WebManager webManager;

    public RSSTestServer(int port) {
        webManager = new WebManager();
        HttpServer rssServer = new HttpServer(webManager.getBosses(), webManager.getWorkers(), port,
                HttpServerConfigBuilder.createDefault());
        rssServer.addServlet(new RSSFeedServlet(null, new String[] { "/" }));
        webManager.add(rssServer);
    }

    @Override
    public void configure(String[] args) {
    }

    @Override
    public void start() throws Exception {
        webManager.start();
    }

    @Override
    public void stop() throws Exception {
        webManager.stop();
    }

}
